@@ -9,7 +9,7 @@ for some of the features of WebService::Google-Hack.
 
 To install the interface please follow these steps:
 
-The web interface for WebService::Google-Hack has been implemented such that, there needs to be a WebService::Google-Hack Server running in the background, so that the client file google_hack.cgi can connect to the server on a specific port, and retrieve results.
+The web interface for WebService::Google-Hack has been implemented such that, there needs to be a WebService::Google-Hack Server running in the background, so that the client file index.cgi can connect to the server on a specific port, and retrieve results.
 
 =head1 Installation Guide
 
@@ -17,10 +17,10 @@ The web interface for WebService::Google-Hack has been implemented such that, th
 
 /webspace/cgi-bin/ghack
 
-2) Next, copy the file named google_hack.cgi, which is given with the 
+2) Next, copy the file named index.cgi, which is given with the 
 distribution of the google-hack package into your cgi-bin/ghack/ directory.
 
-3) Open the google_hack.cgi file (The google_hack.cgi file is in the WebInterface directory of GoogleHack. For eg: WebService/GoogleHack/WebInterface), 
+3) Open the index.cgi file (The index.cgi file is in the WebInterface directory of GoogleHack. For eg: WebService/GoogleHack/WebInterface), 
 and change the lib path to the path where WebService::GoogleHack has been 
 installed on your machine.
 
@@ -28,7 +28,7 @@ installed on your machine.
 
 5) In the ghack_server.pl file, change the following variables accordingly:
 
-Basedir should be the path to the cgi-bin directory in which google_hack.cgi 
+Basedir should be the path to the cgi-bin directory in which index.cgi 
 resides.
 
 $BASEDIR = '/webspace/cgi-bin/ghack'; 
@@ -36,17 +36,9 @@ $BASEDIR = '/webspace/cgi-bin/ghack';
 The localport should be a number above 1024, and less than around 66,000. Make
  sure that localport number is the same on both the client and server side.
 
-$localport = 32983;
+$localport ="";
 
-
-$lock_file = "$BASEDIR/ghack_server.lock";
-
-$error_log = "$BASEDIR/error.log";
-
-
-The lockfile & error_log variables will remain the same. 
-
-6) Now, open the google_hack.cgi  file (which is also given in the  WebInterface directory of GoogleHack),
+6) Now, open the index.cgi  file (which is also given in the  WebInterface directory of GoogleHack),
 
 Set the remote_host, and remote_port variables to the correct values.
 
